@@ -19,11 +19,3 @@ class MissingAttribute(Exception):
 
     def __str__(self):
         return f"{tag} is missing the {attr} attribute"
-
-
-class InvalidTime(Exception):
-    def __init__(self, time):
-        self.t = time
-
-    def __str__(self):
-        return f"Provided time: '{self.t}' is missing a suffix unit"
