@@ -41,7 +41,7 @@ class Google:
         An empty element that controls pausing or other prosodic boundaries between words. Using `<break>` between any pair of tokens is optional. If this element is not present between words, the break is automatically determined based on the linguistic context.
 
         Args:
-            time (str): Sets the length of the break by seconds or milliseconds (e.g. "3s" or "250ms").
+            time (str): Sets the length of the break by seconds or milliseconds (time must be in milliseconds).
             strength (str): Sets the strength of the output's prosodic break by relative terms. Valid values are: "x-weak", weak", "medium", "strong", and "x-strong". The value "none" indicates that no prosodic break boundary should be outputted, which can be used to prevent a prosodic break that the processor would otherwise produce. The other values indicate monotonically non-decreasing (conceptually increasing) break strength between tokens. The stronger boundaries are typically accompanied by pauses.
 
         Raises:
@@ -52,10 +52,7 @@ class Google:
             Speech
         """
         if time:
-            if time.endswith("ms") or time.endswith("ms"):
-                self._speech += f"<break time='{time}'/>"
-            else:
-                raise InvalidTime(time)
+            self._speech += f"<break time='{time}ms'/>"
         elif strength:
             if strength in self._VALID_STRENGTH:
                 self._speech += f"<break strength='{strength}'/>"
